@@ -39,8 +39,8 @@ class DefaultApps : public QWidget
     Q_OBJECT
 
 public:
-    explicit DefaultApps(QWidget *parent = 0);
-    ~DefaultApps();
+    explicit DefaultApps(QWidget *parent = nullptr);
+    ~DefaultApps() override;
 
 signals:
     void defaultAppChanged(const QString&, const QString&);
