@@ -6,32 +6,32 @@
     <message>
         <location filename="../autostartedit.ui" line="14"/>
         <source>Edit</source>
-        <translation type="unfinished"></translation>
+        <translation>Upraviť</translation>
     </message>
     <message>
         <location filename="../autostartedit.ui" line="20"/>
         <source>Name:</source>
-        <translation type="unfinished"></translation>
+        <translation>Meno:</translation>
     </message>
     <message>
         <location filename="../autostartedit.ui" line="27"/>
         <source>Search...</source>
-        <translation type="unfinished"></translation>
+        <translation>Hľadať...</translation>
     </message>
     <message>
         <location filename="../autostartedit.ui" line="47"/>
         <source>Command:</source>
-        <translation type="unfinished"></translation>
+        <translation>Príkaz:</translation>
     </message>
     <message>
         <location filename="../autostartedit.ui" line="57"/>
         <source>Wait for system tray</source>
-        <translation type="unfinished"></translation>
+        <translation>Počkať na systémovú lištu</translation>
     </message>
     <message>
         <location filename="../autostartedit.cpp" line="61"/>
         <source>Select Application</source>
-        <translation type="unfinished"></translation>
+        <translation>Vybrať aplikáciu</translation>
     </message>
 </context>
 <context>
@@ -39,22 +39,22 @@
     <message>
         <location filename="../autostartmodel.cpp" line="193"/>
         <source>Global Autostart</source>
-        <translation type="unfinished"></translation>
+        <translation>Globálne automatické spustenie</translation>
     </message>
     <message>
         <location filename="../autostartmodel.cpp" line="195"/>
         <source>LXQt Autostart</source>
-        <translation type="unfinished"></translation>
+        <translation>Automatické spustenie LXQt</translation>
     </message>
     <message>
         <location filename="../autostartmodel.cpp" line="213"/>
         <source>Location: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Umiestnenie: %1</translation>
     </message>
     <message>
         <location filename="../autostartmodel.cpp" line="215"/>
         <source>Overrides: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Nahradiť: %1</translation>
     </message>
 </context>
 <context>
@@ -62,32 +62,32 @@
     <message>
         <location filename="../autostartpage.ui" line="17"/>
         <source>Delete</source>
-        <translation type="unfinished"></translation>
+        <translation>Vymazať</translation>
     </message>
     <message>
         <location filename="../autostartpage.ui" line="24"/>
         <source>Add</source>
-        <translation type="unfinished"></translation>
+        <translation>Pridať</translation>
     </message>
     <message>
         <location filename="../autostartpage.ui" line="31"/>
         <source>Edit</source>
-        <translation type="unfinished"></translation>
+        <translation>Upraviť</translation>
     </message>
     <message>
         <location filename="../autostartpage.ui" line="44"/>
         <source>Application Autostart</source>
-        <translation type="unfinished"></translation>
+        <translation>Použiť automatické spustenie</translation>
     </message>
     <message>
         <location filename="../autostartpage.cpp" line="143"/>
         <source>Error</source>
-        <translation type="unfinished"></translation>
+        <translation>Chyba</translation>
     </message>
     <message>
         <location filename="../autostartpage.cpp" line="143"/>
         <source>File &apos;%1&apos; already exists!</source>
-        <translation type="unfinished"></translation>
+        <translation>Súbor &apos;%1&apos; už existuje!</translation>
     </message>
 </context>
 <context>
@@ -95,62 +95,62 @@
     <message>
         <location filename="../basicsettings.ui" line="30"/>
         <source>Window Manager</source>
-        <translation type="unfinished"></translation>
+        <translation>Správca okien</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="49"/>
         <source>Search...</source>
-        <translation type="unfinished"></translation>
+        <translation>Hľadať...</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="59"/>
         <source>LXQt Modules</source>
-        <translation type="unfinished"></translation>
+        <translation>Moduly LXQt</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="65"/>
         <source>Start</source>
-        <translation type="unfinished"></translation>
+        <translation>Spustiť</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="72"/>
         <source>Stop</source>
-        <translation type="unfinished"></translation>
+        <translation>Zastaviť</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="111"/>
         <source>Leave Session</source>
-        <translation type="unfinished"></translation>
+        <translation>Opustiť sedenie</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="117"/>
         <source>Ask for confirmation to leave session</source>
-        <translation type="unfinished"></translation>
+        <translation>Požiadať o potvrdenie pre opustenie relácie</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="124"/>
         <source>Lock screen before suspending/hibernating</source>
-        <translation type="unfinished"></translation>
+        <translation>Uzamknúť monitor pred prepnutím do pohotovostného stavu / hibernácie</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="131"/>
         <source>Suspend/hibernate after lock delay:</source>
-        <translation type="unfinished"></translation>
+        <translation>Prepnutie do pohotovostného stavu / hibernácie po uplynutí:</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="144"/>
         <source> ms</source>
-        <translation type="unfinished"></translation>
+        <translation> ms</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="23"/>
         <source>Basic Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Základné nastavenia</translation>
     </message>
     <message>
         <location filename="../basicsettings.cpp" line="156"/>
         <source>Select a window manager</source>
-        <translation type="unfinished"></translation>
+        <translation>Vybrať správcu okien</translation>
     </message>
 </context>
 <context>
@@ -158,12 +158,12 @@
     <message>
         <location filename="../defaultappspage.cpp" line="74"/>
         <source>Select a terminal emulator</source>
-        <translation type="unfinished"></translation>
+        <translation>Vybrať emulátor terminálu</translation>
     </message>
     <message>
         <location filename="../defaultappspage.cpp" line="79"/>
         <source>Select a web browser</source>
-        <translation type="unfinished"></translation>
+        <translation>Vybrať internetový prehliadač</translation>
     </message>
 </context>
 <context>
@@ -171,23 +171,23 @@
     <message>
         <location filename="../defaultappspage.ui" line="23"/>
         <source>Default Applications</source>
-        <translation type="unfinished"></translation>
+        <translation>Predvolené aplikácie</translation>
     </message>
     <message>
         <location filename="../defaultappspage.ui" line="32"/>
         <source>Terminal Emulation:</source>
-        <translation type="unfinished"></translation>
+        <translation>Emulátor terminálu:</translation>
     </message>
     <message>
         <location filename="../defaultappspage.ui" line="52"/>
         <location filename="../defaultappspage.ui" line="79"/>
         <source>Search...</source>
-        <translation type="unfinished"></translation>
+        <translation>Hľadať...</translation>
     </message>
     <message>
         <location filename="../defaultappspage.ui" line="59"/>
         <source>Web Browser:</source>
-        <translation type="unfinished"></translation>
+        <translation>Internetový prehliadač:</translation>
     </message>
 </context>
 <context>
@@ -195,27 +195,27 @@
     <message>
         <location filename="../environmentpage.ui" line="17"/>
         <source>Add</source>
-        <translation type="unfinished"></translation>
+        <translation>Pridaj</translation>
     </message>
     <message>
         <location filename="../environmentpage.ui" line="24"/>
         <source>Delete</source>
-        <translation type="unfinished"></translation>
+        <translation>Odstrániť</translation>
     </message>
     <message>
         <location filename="../environmentpage.ui" line="50"/>
         <source>Environment Variables (Advanced)</source>
-        <translation type="unfinished"></translation>
+        <translation>Premenné prostredia (rozšírené)</translation>
     </message>
     <message>
         <location filename="../environmentpage.ui" line="61"/>
         <source>Variable Name</source>
-        <translation type="unfinished"></translation>
+        <translation>Premenné meno</translation>
     </message>
     <message>
         <location filename="../environmentpage.ui" line="66"/>
         <source>Value</source>
-        <translation type="unfinished"></translation>
+        <translation>Hodnota</translation>
     </message>
 </context>
 <context>
@@ -223,7 +223,7 @@
     <message>
         <location filename="../modulemodel.cpp" line="87"/>
         <source>Running</source>
-        <translation type="unfinished"></translation>
+        <translation>Beží</translation>
     </message>
 </context>
 <context>
@@ -231,42 +231,42 @@
     <message>
         <location filename="../sessionconfigwindow.cpp" line="45"/>
         <source>LXQt Session Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Nastavenie sedenia LXQt</translation>
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="48"/>
         <source>Basic Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Základné nastavenia</translation>
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="54"/>
         <source>Default Applications</source>
-        <translation type="unfinished"></translation>
+        <translation>Predvolené aplikácie</translation>
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="57"/>
         <source>User Directories</source>
-        <translation type="unfinished"></translation>
+        <translation>Adresáre užívateľa</translation>
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="63"/>
         <source>Autostart</source>
-        <translation type="unfinished"></translation>
+        <translation>Automatické spustenie</translation>
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="69"/>
         <source>Environment (Advanced)</source>
-        <translation type="unfinished"></translation>
+        <translation>Prostredie (Rozšírené)</translation>
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="95"/>
         <source>Session Restart Required</source>
-        <translation type="unfinished"></translation>
+        <translation>Vyžaduje sa reštart relácie</translation>
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="96"/>
         <source>Some settings will not take effect until the next log in.</source>
-        <translation type="unfinished"></translation>
+        <translation>Niektoré nastavenia sa prejavia až po ďalšom prihlásení.</translation>
     </message>
 </context>
 <context>
@@ -274,22 +274,22 @@
     <message>
         <location filename="../userlocationspage.cpp" line="116"/>
         <source>Locations for Personal Files</source>
-        <translation type="unfinished"></translation>
+        <translation>Miesto pre osobné súbory</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="185"/>
         <source>LXQt Session Settings - User Directories</source>
-        <translation type="unfinished"></translation>
+        <translation>Nastavenie relácie LXQt - Užívateľské adresáre</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="186"/>
         <source>An error ocurred while applying the settings for the %1 location</source>
-        <translation type="unfinished"></translation>
+        <translation>Pri aplikovaní nastavení sa vyskytla chyba %1</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="202"/>
         <source>Choose Location</source>
-        <translation type="unfinished"></translation>
+        <translation>Vybrať umiestnenie</translation>
     </message>
 </context>
 <context>
@@ -297,82 +297,82 @@
     <message>
         <location filename="../userlocationspage.cpp" line="63"/>
         <source>Desktop</source>
-        <translation type="unfinished"></translation>
+        <translation>Plocha</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="64"/>
         <source>Downloads</source>
-        <translation type="unfinished"></translation>
+        <translation>Stiahnuté</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="65"/>
         <source>Templates</source>
-        <translation type="unfinished"></translation>
+        <translation>Šablóny</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="66"/>
         <source>Public Share</source>
-        <translation type="unfinished"></translation>
+        <translation>Verejne zdieľané</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="67"/>
         <source>Documents</source>
-        <translation type="unfinished"></translation>
+        <translation>Dokumenty</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="68"/>
         <source>Music</source>
-        <translation type="unfinished"></translation>
+        <translation>Hudba</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="69"/>
         <source>Pictures</source>
-        <translation type="unfinished"></translation>
+        <translation>Obrázky</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="70"/>
         <source>Videos</source>
-        <translation type="unfinished"></translation>
+        <translation>Videá</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="73"/>
         <source>Contains all the files which you see on your desktop</source>
-        <translation type="unfinished"></translation>
+        <translation>Obsahuje všetky súbory viditeľné na pracovnej ploche</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="74"/>
         <source>Default folder to save your downloaded files</source>
-        <translation type="unfinished"></translation>
+        <translation>Vybrať predvolený priečinok na uloženie prevzatých súborov</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="75"/>
         <source>Default folder to load or save templates from or to</source>
-        <translation type="unfinished"></translation>
+        <translation>Vybrať predvolený priečinok na uloženie šablón</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="76"/>
         <source>Default folder to publicly share your files</source>
-        <translation type="unfinished"></translation>
+        <translation>Predvolený priečinok pre verejne zdieľané súbory</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="77"/>
         <source>Default folder to load or save documents from or to</source>
-        <translation type="unfinished"></translation>
+        <translation>Predvolený priečinok pre načítanie alebo ukladanie dokumentov</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="78"/>
         <source>Default folder to load or save music from or to</source>
-        <translation type="unfinished"></translation>
+        <translation>Predvolený priečinok pre načítanie alebo ukladanie hudby</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="79"/>
         <source>Default folder to load or save pictures from or to</source>
-        <translation type="unfinished"></translation>
+        <translation>Predvolený priečinok pre načítanie alebo ukladanie obrázkov</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="80"/>
         <source>Default folder to load or save videos from or to</source>
-        <translation type="unfinished"></translation>
+        <translation>Predvolený priečinok pre načítanie alebo ukladanie videí</translation>
     </message>
 </context>
 </TS>
